@@ -1,7 +1,7 @@
 /* Match rules with nonterminals for bison,
 
-   Copyright (C) 1984, 1989, 2000-2002, 2009-2013 Free Software
-   Foundation, Inc.
+   Copyright (C) 1984, 1989, 2000-2002, 2009-2015, 2018-2020 Free
+   Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
